@@ -246,6 +246,7 @@ module Commander
     # Returns array of valid command names found within _args_.
 
     def valid_command_names_from(*args)
+      remove_global_options options, args
       arg_string = args.delete_if { |value| value =~ /^-/ }.join ' '
       commands.keys.find_all { |name| name if arg_string =~ /^#{name}\b/ }
     end
@@ -329,25 +330,30 @@ module Commander
 
     def remove_global_options(options, args)
       options.each do |option|
-        switches = option[:switches].dup
+        switches = option[:switches]
         next if switches.empty?
-
-        if (switch_has_arg = switches.any? { |s| s =~ /[ =]/ })
-          switches.map! { |s| s[0, s.index('=') || s.index(' ') || s.length] }
-        end
-
+        option_takes_argument = switches.any? { |s| s =~ /[ =]/ }
         switches = expand_optionally_negative_switches(switches)
 
-        past_switch, arg_removed = false, false
-        args.delete_if do |arg|
-          break if arg == '--'
-          if switches.any? { |s| s[0, arg.length] == arg }
-            arg_removed = !switch_has_arg
-            past_switch = true
-          elsif past_switch && !arg_removed && arg !~ /^-/
-            arg_removed = true
+        option_argument_needs_removal = false
+        args.delete_if do |token|
+          break if token == '--'
+
+          # Use just the portion of the token before the = when
+          # comparing switches.
+          index_of_equals = token.index('=') if option_takes_argument
+          token = token[0, index_of_equals] if index_of_equals
+          token_contains_option_argument = !index_of_equals.nil?
+
+          if switches.any? { |s| s[0, token.length] == token }
+            option_argument_needs_removal =
+              option_takes_argument && !token_contains_option_argument
+            true
+          elsif option_argument_needs_removal && token !~ /^-/
+            option_argument_needs_removal = false
+            true
           else
-            arg_removed = true
+            option_argument_needs_removal = false
             false
           end
         end
@@ -395,7 +401,7 @@ module Commander
     def global_option_proc(switches, &block)
       lambda do |value|
         unless active_command.nil?
-          active_command.proxy_options << [Runner.switch_to_sym(switches.last), value]
+          active_command.global_options << [Runner.switch_to_sym(switches.last), value]
         end
         yield value if block && !value.nil?
       end
