@@ -100,6 +100,17 @@ describe Commander do
       expect(quiet).to be true
     end
 
+    it 'should be inherited by commands when provided before the command name' do
+      option = nil
+      new_command_runner '--global-option', 'option-value', 'command_name' do
+        global_option('--global-option=GLOBAL', 'A global option')
+        command :command_name do |c|
+          c.when_called { |_, options| option = options.global_option }
+        end
+      end.run!
+      expect(option).to eq('option-value')
+    end
+
     it 'should be inherited by commands even when a block is present' do
       quiet = nil
       new_command_runner 'foo', '--quiet' do
@@ -132,6 +143,57 @@ describe Commander do
       end.run!
       expect(quiet).to be false
     end
+
+    it 'should allow command arguments before the global option' do
+      config = nil
+      args = nil
+      new_command_runner 'foo', '--config', 'config-value', 'arg1', 'arg2' do
+        global_option('-c', '--config CONFIG', String)
+        command :foo do |c|
+          c.when_called do |arguments, options|
+            options.default(config: 'default')
+            args = arguments
+            config = options.config
+          end
+        end
+      end.run!
+      expect(config).to eq('config-value')
+      expect(args).to eq(%w(arg1 arg2))
+    end
+
+    it 'should allow command arguments after the global option' do
+      config = nil
+      args = nil
+      new_command_runner 'foo', 'arg1', 'arg2', '--config', 'config-value' do
+        global_option('-c', '--config CONFIG', String)
+        command :foo do |c|
+          c.when_called do |arguments, options|
+            options.default(config: 'default')
+            args = arguments
+            config = options.config
+          end
+        end
+      end.run!
+      expect(config).to eq('config-value')
+      expect(args).to eq(%w(arg1 arg2))
+    end
+
+    it 'allows global options in the form option=value' do
+      config = nil
+      args = nil
+      new_command_runner 'test', 'arg1', '--config=config-value', 'arg2' do
+        global_option('-c', '--config CONFIG', String)
+        command :test do |c|
+          c.when_called do |arguments, options|
+            options.default(config: 'default')
+            args = arguments
+            config = options.config
+          end
+        end
+      end.run!
+      expect(config).to eq('config-value')
+      expect(args).to eq(%w[arg1 arg2])
+    end
   end
 
   describe '#parse_global_options' do
@@ -326,6 +388,20 @@ describe Commander do
       command_runner.remove_global_options options, args
       expect(args).to eq(%w(--versionCode something))
     end
+
+    it 'should remove specified switches value provided via equals' do
+      options = [{ switches: ['--global GLOBAL'] }]
+      args = ['--command', '--global=option-value', 'arg']
+      command_runner.remove_global_options options, args
+      expect(args).to eq(['--command', 'arg'])
+    end
+
+    it 'should not remove extra values after switches' do
+      options = [{ switches: ['--global GLOBAL'] }]
+      args = ['--global', '--command', 'arg']
+      command_runner.remove_global_options options, args
+      expect(args).to eq(['--command', 'arg'])
+    end
   end
 
   describe '--trace' do
@@ -334,7 +410,7 @@ describe Commander do
         new_command_runner 'foo' do
           command(:foo) { |c| c.when_called { fail 'cookies!' } }
         end.run!
-      end.to raise_error(SystemExit, /error: cookies!. Use --trace/)
+      end.to raise_error(TestSystemExit, /error: cookies!. Use --trace/)
     end
 
     it 'should display callstack when using this switch' do
@@ -363,7 +439,7 @@ describe Commander do
         new_command_runner 'help', '--trace' do
           never_trace!
         end.run!
-      end.to raise_error(SystemExit, /invalid option: --trace/)
+      end.to raise_error(TestSystemExit, /invalid option: --trace/)
     end
 
     it 'should not prompt to use --trace switch on errors' do
@@ -373,7 +449,7 @@ describe Commander do
           never_trace!
           command(:foo) { |c| c.when_called { fail 'cookies!' } }
         end.run!
-      rescue SystemExit => e
+      rescue TestSystemExit => e
         msg = e.message
       end
       expect(msg).to match(/error: cookies!/)
@@ -430,7 +506,7 @@ describe Commander do
     it 'should output an invalid option message' do
       expect do
         run('test', '--invalid-option')
-      end.to raise_error(SystemExit, /invalid option: --invalid-option/)
+      end.to raise_error(TestSystemExit, /invalid option: --invalid-option/)
     end
   end
 
@@ -438,7 +514,7 @@ describe Commander do
     it 'should output an invalid command message' do
       expect do
         run('foo')
-      end.to raise_error(SystemExit, /invalid command. Use --help for more information/)
+      end.to raise_error(TestSystemExit, /invalid command. Use --help for more information/)
     end
   end
 
@@ -446,7 +522,7 @@ describe Commander do
     it 'should output an invalid command message' do
       expect do
         run('help', 'does_not_exist')
-      end.to raise_error(SystemExit, /invalid command. Use --help for more information/)
+      end.to raise_error(TestSystemExit, /invalid command. Use --help for more information/)
     end
   end
 
@@ -454,7 +530,7 @@ describe Commander do
     it 'should output an invalid command message' do
       expect do
         run('--help', 'does_not_exist')
-      end.to raise_error(SystemExit, /invalid command. Use --help for more information/)
+      end.to raise_error(TestSystemExit, /invalid command. Use --help for more information/)
     end
   end
 
@@ -462,7 +538,7 @@ describe Commander do
     it 'should output an invalid option message' do
       expect do
         run('--help', 'test', '--invalid-option')
-      end.to raise_error(SystemExit, /invalid option: --invalid-option/)
+      end.to raise_error(TestSystemExit, /invalid option: --invalid-option/)
     end
   end
 
@@ -495,6 +571,13 @@ describe Commander do
       expect(command_runner.command_name_from_args).to eq('test')
     end
 
+    it 'should locate command when provided after a global argument with value' do
+      new_command_runner '--global-option', 'option-value', 'test' do
+        global_option('--global-option=GLOBAL', 'A global option')
+      end
+      expect(command_runner.command_name_from_args).to eq('test')
+    end
+
     it 'should support multi-word commands' do
       new_command_runner '--help', '--arbitrary', 'some', 'long', 'command', 'foo'
       command('some long command') {}
